============
Transactions
============

.. image:: https://travis-ci.org/zopefoundation/transaction.png?branch=master
        :target: https://travis-ci.org/zopefoundation/transaction

.. image:: https://readthedocs.org/projects/transaction/badge/?version=latest
        :target: http://transaction.readthedocs.org/en/latest/
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/transaction.svg
        :target: https://pypi.python.org/pypi/transaction
        :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/transaction.svg
        :target: https://pypi.python.org/pypi/transaction
        :alt: Python versions

This package contains a generic transaction implementation for Python. It is
mainly used by the ZODB.

See http://transaction.readthedocs.org/en/latest for narrative documentation
on its usage.

